@@ -13,10 +13,12 @@ from ..__common__ import *
 
 
 __examples__ = {
-    'enc(bacon|bacon_cipher|baconian-cipher|bacon-ab|bacon-AB)': {
-        'this is a test': "baaba aabbb abaaa baaab  abaaa baaab  aaaaa  baaba aabaa baaab baaba",
+    'enc(bacon|bacon_cipher|baconian-cipher|bacon-ab|bacon_AB)': {
+        'this is a test': "baabaaabbbabaaabaaab abaaabaaab aaaaa baabaaabaabaaabbaaba",
+    },
+    'enc(bacon-01|bacon_01)': {
+        'this is a test': "10010001110100010001 0100010001 00000 10010001001000110010",
     },
-    'enc(bacon-01)': {'this is a test': "10010 00111 01000 10001  01000 10001  00000  10010 00100 10001 10010"},
 }
 
 
@@ -24,9 +26,9 @@ ENCMAP = {
     'A': "aaaaa", 'B': "aaaab", 'C': "aaaba", 'D': "aaabb", 'E': "aabaa", 'F': "aabab", 'G': "aabba", 'H': "aabbb",
     'I': "abaaa", 'J': "abaaa", 'K': "abaab", 'L': "ababa", 'M': "ababb", 'N': "abbaa", 'O': "abbab", 'P': "abbba",
     'Q': "abbbb", 'R': "baaaa", 'S': "baaab", 'T': "baaba", 'U': "baabb", 'V': "baabb", 'W': "babaa", 'X': "babab",
-    'Y': "babba", 'Z': "babbb", ' ': "",
+    'Y': "babba", 'Z': "babbb", ' ': " ",
 }
 
 
-add_map("bacon", ENCMAP, sep=" ", ignore_case="both", pattern=r"bacon(?:(?:ian)?[-_]cipher)?([\-_].{2})?$")
+add_map("bacon", ENCMAP, ignore_case="both", pattern=r"bacon(?:(?:ian)?[-_]cipher)?([\-_].{2})?$")
 
